package cn.skcks.study.rxjava;

import io.reactivex.rxjava3.core.Flowable;
import io.reactivex.rxjava3.core.Observable;
import io.reactivex.rxjava3.core.ObservableOnSubscribe;
import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.schedulers.Schedulers;
import lombok.extern.slf4j.Slf4j;
import org.junit.jupiter.api.Test;
import org.springframework.boot.test.context.SpringBootTest;

@Slf4j
@SpringBootTest(webEnvironment = SpringBootTest.WebEnvironment.NONE)
public class RxJavaStudyStarterTest {
    @Test
    void contextLoads() {
      log.info("Hello, RxJava!");
        Disposable disposable = Flowable.just("Hello world").subscribe(System.out::println);
        disposable.dispose();

        Observable<Integer> integerObservable = Observable.create((ObservableOnSubscribe<Integer>) emitter -> {
            for (int i = 1; i <= 5; i++) {
                emitter.onNext(i);
                Thread.sleep((long) (Math.random() * 100));
            }
            emitter.onComplete();
        }).subscribeOn(Schedulers.io())
        .observeOn(Schedulers.newThread());

        integerObservable.subscribe(item -> System.out.println("println: Subscribe Next: " + item));
        integerObservable.subscribe(item -> log.info("[logInfo] Subscribe Next: {}", item));
        integerObservable.blockingSubscribe();

        Observable<Integer> take = Observable.fromArray(1, 2, 3, 4, 5)
                .observeOn(Schedulers.computation()).skip(2).take(1);
        take.subscribe(System.out::println);
    }
}
